@@ -1,11 +1,11 @@
 import sys
-from os import path
 import datetime
 import pkgutil
+import simplecfg
 
 PROGRAM_NAME = "create-license"
 PROGRAM_CMD = "create-license"
-PROGRAM_VERSION = "2.0.5"
+PROGRAM_VERSION = "2.0.8"
 PROGRAM_AUTHOR = "Max Loiacono"
 PROGRAM_URL = "https://github.com/itsmaxymoo/create-license"
 
@@ -17,22 +17,19 @@ ENABLED_LICENSES = [
 	("lgpl-3", "GNU Lesser General Public License 3.0"),
 	("mit", "MIT License"),
 	("mpl-2", "Mozilla Public License, version 2.0"),
-	("none", "Public domain (+liability, warranty)")
+	("none", "Public domain (+liability, warranty)"),
+	("closed", "Closed source license template")
 ]
 
-config = ""
-config_file_path = path.expanduser("~") + "/.create_license"
-f = open(config_file_path, mode="a", encoding="utf-8")
+config = simplecfg.Config(simplecfg.dir.HOME, ".create_license")
 
 
-def main():
+def _main():
 	# Configuration file
-	global f, config
-	f = open(config_file_path, mode="r", encoding="utf-8")
-	config = f.read().replace("\n", "").replace("\r", "")
-	if len(config) == 0:
+	global config
+	if len(config.get("name")) == 0:
 		print("Please set the name to be automatically inserted into licenses.")
-		set_name()
+		_set_name()
 
 	# Command line arguments
 	cli_opt = ""
@@ -40,20 +37,20 @@ def main():
 		cli_opt = sys.argv[1]
 
 	if cli_opt in ["", "-h", "--help", "help"]:
-		show_help()
+		_show_help()
 	elif cli_opt == "list":
-		list_licenses()
+		_list_licenses()
 	elif cli_opt == "set-name":
-		set_name()
+		_set_name()
 	elif len(sys.argv) > 2:
-		create_license(sys.argv[1], sys.argv[2])
+		_create_license(sys.argv[1], sys.argv[2])
 	elif len(sys.argv) > 1:
-		create_license(sys.argv[1])
+		_create_license(sys.argv[1])
 
 	exit(0)
 
 
-def create_license(license_name, filename="LICENSE"):
+def _create_license(license_name, filename="LICENSE"):
 	current_year = str(datetime.date.today().year)
 	license_text = ""
 
@@ -64,7 +61,7 @@ def create_license(license_name, filename="LICENSE"):
 
 	if license_text != "":
 		license_text = license_text.replace("{{YEAR}}", current_year)
-		license_text = license_text.replace("{{NAME}}", config)
+		license_text = license_text.replace("{{NAME}}", config.get("name"))
 
 		try:
 			license_file = open(filename, mode="x", encoding="utf-8")
@@ -77,7 +74,7 @@ def create_license(license_name, filename="LICENSE"):
 		print("ERROR: License \"" + license_name.lower() + "\" not found!")
 
 
-def show_help():
+def _show_help():
 	print(PROGRAM_NAME + " version " + PROGRAM_VERSION + " by " + PROGRAM_AUTHOR)
 	print("See at: " + PROGRAM_URL + "\n")
 	print("Usage:\t" + PROGRAM_CMD + " [option]")
@@ -91,7 +88,7 @@ def show_help():
 	print("\t[license] [file]\tcreate a new [license] with filename [file]")
 
 
-def list_licenses():
+def _list_licenses():
 	print("License\t\tDescription\n")
 
 	for l in ENABLED_LICENSES:
@@ -103,11 +100,7 @@ def list_licenses():
 	print("https://choosealicense.com/licenses")
 
 
-def set_name():
+def _set_name():
 	name = input("Your name: ")
 	print("Hi, " + name)
-	f = open(config_file_path, mode="w", encoding="utf-8")
-	f.write(name)
-
-
-main()
+	config.set("name", name)
